Module utils

Module utils 

Structs

InspectData
Shape of inspected data
StatsData
Shape of stats data

Functions

get_container_name
Gets the name of a docker container by the container_id passed as argument
get_containers_from_stack
Gets container names from a given stack
get_timestamp
Gets the current time on the system in readable format
is_terminal
Determine if stdout is going to terminal
kill_containers
Force removes all docker containers provided in argument
list_containers
Lists currently running docker containers
parse_inspect_data
Parses inspected data
parse_stats_data
Parse stats data
spawn_container_logger
Spawns threads to handle container logs
update_container_by_name
Updates a container by the container_name provided as argument