Structs
- Inspect
Data - Shape of inspected data
- Stats
Data - Shape of stats data
Functions
- get_
container_ name - Gets the name of a docker container by the container_id passed as argument
- get_
containers_ from_ stack - Gets container names from a given stack
- get_
timestamp - Gets the current time on the system in readable format
- is_
terminal - Determine if stdout is going to terminal
- kill_
containers - Force removes all docker containers provided in argument
- list_
containers - Lists currently running docker containers
- parse_
inspect_ data - Parses inspected data
- parse_
stats_ data - Parse stats data
- spawn_
container_ logger - Spawns threads to handle container logs
- update_
container_ by_ name - Updates a container by the container_name provided as argument